"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.RemoteFluidObjectHandle = void 0;
const core_utils_1 = require("@fluidframework/core-utils");
const container_runtime_1 = require("@fluidframework/container-runtime");
const runtime_utils_1 = require("@fluidframework/runtime-utils");
/**
 * This handle is used to dynamically load a Fluid object on a remote client and is created on parsing a serialized
 * FluidObjectHandle.
 * This class is used to generate an IFluidHandle when de-serializing any all handles (including handles to DDSes,
 * custom objects) that are stored in SharedObjects. The Data Store or SharedObject corresponding to the
 * IFluidHandle can be retrieved by calling `get` on it.
 */
class RemoteFluidObjectHandle {
    /**
     * @deprecated Will be removed in future major release. Migrate all usage of IFluidRouter to the "entryPoint" pattern. Refer to Removing-IFluidRouter.md
     */
    get IFluidRouter() {
        return this;
    }
    get IFluidHandleContext() {
        return this;
    }
    get IFluidHandle() {
        return this;
    }
    /**
     * Creates a new RemoteFluidObjectHandle when parsing an IFluidHandle.
     * @param absolutePath - The absolute path to the handle from the container runtime.
     * @param routeContext - The root IFluidHandleContext that has a route to this handle.
     */
    constructor(absolutePath, routeContext) {
        this.absolutePath = absolutePath;
        this.routeContext = routeContext;
        this.isAttached = true;
        (0, core_utils_1.assert)(absolutePath.startsWith("/"), 0x19d /* "Handles should always have absolute paths" */);
    }
    async get() {
        if (this.objectP === undefined) {
            // Add `viaHandle` header to distinguish from requests from non-handle paths.
            const request = {
                url: this.absolutePath,
                headers: { [container_runtime_1.RuntimeHeaders.viaHandle]: true },
            };
            this.objectP = this.routeContext
                .resolveHandle(request)
                .then((response) => {
                if (response.mimeType === "fluid/object") {
                    const fluidObject = response.value;
                    return fluidObject;
                }
                throw (0, runtime_utils_1.responseToException)(response, request);
            });
        }
        return this.objectP;
    }
    attachGraph() {
        return;
    }
    bind(handle) {
        handle.attachGraph();
    }
    /**
     * @deprecated Will be removed in future major release. Migrate all usage of IFluidRouter to the "entryPoint" pattern. Refer to Removing-IFluidRouter.md
     */
    async request(request) {
        try {
            // eslint-disable-next-line import/no-deprecated
            const object = await this.get();
            const router = object.IFluidRouter;
            return router === undefined
                ? (0, runtime_utils_1.create404Response)(request)
                : await router.request(request);
        }
        catch (error) {
            return (0, runtime_utils_1.exceptionToResponse)(error);
        }
    }
}
exports.RemoteFluidObjectHandle = RemoteFluidObjectHandle;
//# sourceMappingURL=remoteObjectHandle.cjs.map